Versions of ToFu: — tofu v1.1

# Versions of ToFu:

Many versions of ToFu have been developped before reaching a stable and somewhat satisfactory state. Several versions were already used for producing physcis results and tomographic inversions before the open-source release, which requires documentation and a certain degree of user-friendlyness, thus more work.

The versioning convention used by ToFu is semantic versioning and the module metadata is implemented according to PEP426.

The following only lists the versions advanced enough for release:

- 1.1.0 (default)

    This is the first version released in open-source, it only includes the geometry module (for diagnostic designing and synthetic diagnostic) and the pre-treatment module (for data handling)

## Indices and tables

- Homepage
- Index
- Module Index
- Search Page